import 'dart:convert';

class StatisticsData {
  final int totalCount;
  final int recentCount;
  final int firstPlayedArtistsCount;
  final int firstPlayedTracksCount;
  final int selectedPeriod;
  final DateTime lastScrobble;

  const StatisticsData({
    required this.totalCount,
    required this.recentCount,
    required this.firstPlayedArtistsCount,
    required this.firstPlayedTracksCount,
    required this.selectedPeriod,
    required this.lastScrobble,
  });

  factory StatisticsData.fromJson(Map<String, dynamic> json) {
    return StatisticsData(
      totalCount: json['totalCount'] != null ? json['totalCount'] as int : 0,
      recentCount: json['recentCount'] != null ? json['recentCount'] as int : 0,
      firstPlayedArtistsCount:
          json['firstPlayedArtistsCount'] != null ? json['firstPlayedArtistsCount'] as int : 0,
      firstPlayedTracksCount:
          json['firstPlayedTracksCount'] != null ? json['firstPlayedTracksCount'] as int : 0,
      selectedPeriod: json['selectedPeriod'] != null ? json['selectedPeriod'] as int : 0,
      lastScrobble: (json['lastScrobble'] != null && json['lastScrobble']['date'] != null)
          ? DateTime.parse(
              json['lastScrobble']['date'],
            )
          : DateTime.now(),
    );
  }

  factory StatisticsData.createEmpty() {
    return StatisticsData.fromJson({});
  }

  String toString() {
    Map<String, dynamic> map = {
      'totalCount': this.totalCount,
      'recentCount': this.recentCount,
      'firstPlayedArtistsCount': this.firstPlayedArtistsCount,
      'firstPlayedTracksCount': this.firstPlayedTracksCount,
      'selectedPeriod': this.selectedPeriod,
      'lastScrobble': {
        'date': this.lastScrobble.toString(),
      },
    };

    return jsonEncode(map);
  }
}
